@@ -63,6 +63,9 @@ abbreviate_units = True
 canonical_units = False
 # This cannot be enabled without loose units (e.g., s + 1, or s * 'R' * 'C' + 1 would fail).
 check_units = True
+# Set to 'none' to print s - p; None to print SymPy default form -p + s.
+# Note, SymPy will convert s - -1 to 1 + s unless Add is used with evaluate=False
+printing_order = None
 
 # Use X11 colours so that they will work with graphziv and dot2tex.
 colours = {'startnode': 'green', 'endnode': 'green',
