@@ -64,12 +64,28 @@ class FourierDomain(Domain):
     is_transform_domain = True    
 
     
+class NormFourierDomain(Domain):
+    domain = 'norm fourier'
+    domain_label = 'Normalized frequency'
+    domain_units = 1
+    is_norm_fourier_domain = True
+    is_transform_domain = True        
+
+    
 class AngularFourierDomain(Domain):
     domain = 'angular fourier'
     domain_label = 'Angular frequency'
     domain_units = uu.rad / uu.s
     is_angular_fourier_domain = True
-    is_transform_domain = True    
+    is_transform_domain = True
+
+    
+class NormAngularFourierDomain(Domain):
+    domain = 'norm angular fourier'
+    domain_label = 'Normalized angular frequency'
+    domain_units = uu.rad
+    is_norm_angular_fourier_domain = True
+    is_transform_domain = True        
     
 
 class PhasorTimeDomain(Domain):
