@@ -1,3 +1,11 @@
+"""This module defines additional functions to those defined by SymPy.
+They are for internal use by Lcapy.  The user versions are defined in
+function.py.
+
+Copyright 2020--2021 Michael Hayes, UCECE
+
+"""
+
 import sympy as sym
 from sympy.core import S, Integer
 from sympy.core.logic import fuzzy_not
@@ -58,7 +66,7 @@ class sincn(sym.Function):
     @classmethod
     def eval(cls, val):
         """
-        Evaluates the normalised sinc (cardinal sine) function.
+        Evaluates the normalized sinc (cardinal sine) function.
         This is what NumPy uses but not SymPy.
         """
 
@@ -79,7 +87,7 @@ class sincu(sym.Function):
     @classmethod
     def eval(cls, val):
         """
-        Evaluates the unnormalised sinc (cardinal sine) function.
+        Evaluates the unnormalized sinc (cardinal sine) function.
         This is what SymPy uses but not NumPy.
         """
 
