@@ -1,4 +1,5 @@
 """This module wraps SymPy functions and provides a few others.
+The underlying SymPy function is obtained with the sympy attribute.
 
 Copyright 2014--2021 Michael Hayes, UCECE
 """
@@ -6,11 +7,28 @@ Copyright 2014--2021 Michael Hayes, UCECE
 from .units import u as uu
 import sympy as sym
 
+__all__ = ('conjugate', 'sqrt', 'exp', 'log', 'log10',
+           'sin', 'cos', 'tan', 'cot',
+           'asin', 'acos', 'atan', 'atan2', 'acot',
+           'sinh', 'cosh', 'tanh', 'coth',
+           'asinh', 'acosh', 'atanh', 'acoth',
+           'gcd', 'sign', 'diff', 'integrate',
+           'u', 'H', 'heaviside', 'Heaviside', 'delta', 'DiracDelta',
+           'ui', 'us', 'unitimpulse', 'unitstep', 'UnitImpulse', 'UnitStep',
+           'rect', 'sinc', 'sincn', 'sincu', 'psinc', 'tri', 'trap', 'Sum')
+
+
 class Function(object):
 
     def __init__(self, arg):
         self.expr = arg
     
+    @property
+    def sympy(self):
+        """Return SymPy expression."""
+        
+        return self.expr
+
     def __call__(self, *args):
 
         e_args = [expr(arg) for arg in args]
@@ -26,8 +44,9 @@ class Function(object):
 
         result = cls(result)        
             
-        if e_args[0].is_phase and self.expr in (sym.sin, sym.cos, sym.tan, sym.exp,
-                                                sym.sinh, sym.cosh, sym.tanh):
+        if (e_args[0].is_phase and
+            self.expr in (sym.sin, sym.cos, sym.tan, sym.cot, sym.exp,
+                          sym.sinh, sym.cosh, sym.tanh, sym.coth)):
             result.part = ''
         elif self.expr in (sym.atan, sym.atan2):
             result.units = uu.rad
@@ -59,11 +78,11 @@ class Log10(Function):
 
 
 class SincnFunction(Function):
-    """Normalised sinc function :math:`\sin(\pi x)/(\pi x)`."""
+    """Normalized sinc function :math:`\sin(\pi x)/(\pi x)`."""
 
     
 class SincuFunction(Function):
-    """Unnormalised sinc function :math:`\sin(x)/(x)`."""
+    """Unnormalized sinc function :math:`\sin(x)/(x)`."""
 
     
 class PsincFunction(Function):
@@ -104,12 +123,16 @@ cosh = Function(sym.cosh)
 
 tanh = Function(sym.tanh)
 
+coth = Function(sym.coth)
+
 asinh = Function(sym.asinh)
 
 acosh = Function(sym.acosh)
 
 atanh = Function(sym.atanh)
 
+acoth = Function(sym.acoth)
+
 gcd = Function(sym.gcd)
 
 sign = Function(sym.sign)
@@ -123,19 +146,20 @@ u = H = heaviside = Heaviside = Function(sym.Heaviside)
 delta = DiracDelta = Function(sym.DiracDelta)
 
 
-# def delta(expr1):
-#    
-#     if not hasattr(expr1, 'expr'):
-#         expr1 = expr(expr1)
-#     if expr1.is_discrete_time_domain or expr1.is_discrete_fourier_domain:
-#         return UnitImpulse(expr1)        
-#    
-#     return DiracDelta(expr1)
-
-
 def _ex(expr):
+    """De-lcapify expression."""
+    
     if hasattr(expr, 'expr'):
         return expr.expr
+    elif isinstance(expr, tuple):
+        return tuple([_ex(arg) for arg in expr])
+    elif isinstance(expr, list):
+        return [_ex(arg) for arg in expr]
+    elif isinstance(expr, dict):
+        ret = {}
+        for key, val in expr.items():
+            ret[_ex(key)] = _ex(val)
+        return ret
     return expr
 
 
@@ -164,7 +188,13 @@ class MatMul(sym.MatMul):
         return expr(super(MatMul, cls).__new__(cls, _ex(op1), _ex(op2), **options))
 
 
-from .extrafunctions import UnitImpulse, UnitStep
+class Sum(sym.Sum):
+    def __new__(cls, op1, op2, **options):
+        return expr(super(Sum, cls).__new__(cls, _ex(op1), _ex(op2), **options))
+    
+
+from .extrafunctions import UnitImpulse as UnitImpulse1
+from .extrafunctions import UnitStep as UnitStep1
 from .extrafunctions import sincn as sincn1
 from .extrafunctions import sincu as sincu1
 from .extrafunctions import psinc as psinc1
@@ -173,9 +203,9 @@ from .extrafunctions import tri as tri1
 from .extrafunctions import trap as trap1
 
 
-ui = unitimpulse = Function(UnitImpulse)
+ui = unitimpulse = UnitImpulse = Function(UnitImpulse1)
 
-us = unitstep = Function(UnitStep)
+us = unitstep = UnitStep = Function(UnitStep1)
 
 rect = Function(rect1)
 
