@@ -7,12 +7,12 @@ Copyright 2020--2021 Michael Hayes, UCECE
 
 from __future__ import division
 from .domains import DiscreteFourierDomain
-from .fourier import inverse_fourier_transform
+from .inverse_fourier import inverse_fourier_transform
 from .functions import exp
 from .sym import j, oo, pi
 from .seqexpr import SequenceExpression
 from .dsym import nsym, ksym, zsym
-from .dft import IDFT
+from .inverse_dft import IDFT
 from sympy import Sum
 
 __all__ = ('kexpr', )
@@ -25,15 +25,16 @@ class DiscreteFourierDomainExpression(DiscreteFourierDomain, SequenceExpression)
     def __init__(self, val, **assumptions):
 
         check = assumptions.pop('check', True)
-        assumptions['real'] = True
+        if 'integer' not in assumptions:
+            assumptions['real'] = True           
         
         super(DiscreteFourierDomainExpression, self).__init__(val, **assumptions)
 
         expr = self.expr
-        if check and expr.find(zsym) != set():
+        if check and expr.has(zsym):
             raise ValueError(
                 'k-domain expression %s cannot depend on z' % expr)
-        if check and expr.find(nsym) != set() and not expr.has(Sum):
+        if check and expr.has(nsym) and not expr.has(Sum):
             raise ValueError(
                 'k-domain expression %s cannot depend on n' % expr)
 
@@ -78,9 +79,9 @@ class DiscreteFourierDomainExpression(DiscreteFourierDomain, SequenceExpression)
         from .nexpr import n
 
         if N is None:
-            from .sym import sympify
-            
-            N = sympify('N')
+            from .sym import symsymbol
+
+            N = symsymbol('N', integer=True, positive=True)            
 
         result = IDFT(self.expr, ksym, nsym, N, evaluate=evaluate)
         return self.change(result, domain='discrete time')
@@ -92,8 +93,16 @@ class DiscreteFourierDomainExpression(DiscreteFourierDomain, SequenceExpression)
 def kexpr(arg, **assumptions):
     """Create kExpr object.  If `arg` is ksym return k"""
 
+    from .expr import Expr
+    
     if arg is ksym:
         return k
+
+    if isinstance(arg, Expr):
+        if assumptions == {}:
+            return arg
+        return arg.__class__(arg, **assumptions)
+    
     return DiscreteFourierDomainExpression(arg, **assumptions)
 
 
@@ -101,4 +110,4 @@ from .expressionclasses import expressionclasses
 
 classs = expressionclasses.register('discrete fourier', DiscreteFourierDomainExpression)
 
-k = DiscreteFourierDomainExpression('k')
+k = DiscreteFourierDomainExpression('k', integer=True)
