@@ -1,3 +1,10 @@
+"""This module provides the NetlistHelper class used by the
+NetlistMaker and LadderMaker classes.
+
+Copyright 2020 Michael Hayes, UCECE
+
+"""
+
 class NetlistHelper(object):
 
     evalf = False
@@ -14,6 +21,10 @@ class NetlistHelper(object):
     def _make_id(self, kind):
         """Make identifier"""
 
+        # TODO, use ComponentNamer.  Perhaps the names
+        # should try to follow the value names, say when generated
+        # by the random network generator?  This will avoid confusion.
+        
         if not hasattr(self, '_anon'):
             self._anon = {}            
 
