@@ -10,11 +10,11 @@ from .domains import DiscreteTimeDomain
 from .seqexpr import SequenceExpression
 from .sequence import Sequence
 from .functions import exp
-from .sym import j, oo, pi, fsym
+from .sym import j, oo, pi, fsym, oo
 from .dsym import nsym, ksym, zsym, dt
 from .ztransform import ztransform
 from .dft import DFT
-from sympy import Sum, summation, limit
+from sympy import Sum, summation, limit, DiracDelta
 
 
 __all__ = ('nexpr', )
@@ -28,15 +28,16 @@ class DiscreteTimeDomainExpression(DiscreteTimeDomain, SequenceExpression):
     def __init__(self, val, **assumptions):
 
         check = assumptions.pop('check', True)
-        assumptions['real'] = True        
+        if 'integer' not in assumptions:
+            assumptions['real'] = True   
         
         super(DiscreteTimeDomainExpression, self).__init__(val, **assumptions)
 
         expr = self.expr
-        if check and expr.find(zsym) != set() and not expr.has(Sum):
+        if check and expr.has(zsym) and not expr.has(Sum):
             raise ValueError(
                 'n-domain expression %s cannot depend on z' % expr)
-        if check and expr.find(ksym) != set() and not expr.has(Sum):
+        if check and expr.has(ksym) and not expr.has(Sum):
             raise ValueError(
                 'n-domain expression %s cannot depend on k' % expr)            
 
@@ -66,9 +67,10 @@ class DiscreteTimeDomainExpression(DiscreteTimeDomain, SequenceExpression):
     def integrate(self):
         """First order integration."""
 
-        from .sym import sympify
+        from .sym import symsymbol
         from .utils import factor_const
-        from .functions import UnitImpulse, u
+        from .extrafunctions import UnitImpulse
+        from .functions import u        
 
         # TODO, get SymPy to optimize this case.
         expr = self.expr
@@ -76,7 +78,7 @@ class DiscreteTimeDomainExpression(DiscreteTimeDomain, SequenceExpression):
         if expr.is_Function and expr.func == UnitImpulse:
             return dt * u(expr.args[0]) * const
         
-        msym = sympify('m', real=True)
+        msym = symsymbol('m', integer=True)
         result = dt * summation(self.subs(msym).expr, (msym, -oo, nsym))
         
         return self.__class__(result, **self.assumptions)
@@ -130,9 +132,9 @@ class DiscreteTimeDomainExpression(DiscreteTimeDomain, SequenceExpression):
         from .kexpr import k
 
         if N is None:
-            from .sym import sympify
+            from .sym import symsymbol
             
-            N = sympify('N')
+            N = symsymbol('N', integer=True, positive=True)
 
         result = DFT(self.expr, nsym, ksym, N, evaluate=evaluate)
         return self.change(result, domain='discrete fourier')
@@ -153,31 +155,53 @@ class DiscreteTimeDomainExpression(DiscreteTimeDomain, SequenceExpression):
 
         return self.seq((n1, n2)).extent()
 
-    def discrete_time_fourier_transform(self, **assumptions):
-        """Convert to Fourier domain using discrete time Fourier transform."""
+    def discrete_time_fourier_transform(self, var=None,
+                                        images=oo, **assumptions):
+        """Convert to Fourier domain using discrete time Fourier transform.
 
-        assumptions = self.assumptions.merge_and_infer(self, **assumptions)
-        if assumptions.is_causal:
-            return self.ZT(**assumptions).DTFT()
+        Use `images = 0` to avoid the infinite number of spectral images.
+        """
 
+        return self.DTFT(var, images, **assumptions)
+
+    def DTFT(self, var=None, images=oo, **assumptions):
+        """Convert to Fourier domain using discrete time Fourier transform.
+
+        Use `images = 0` to avoid the infinite number of spectral images.
+        """
+
+        from .extrafunctions import UnitStep        
+        from .symbols import f, omega, Omega, F
         from .fexpr import fexpr
+        from .dtft import DTFT        
+        
+        if var is None:
+            var = f
+        if id(var) not in (id(f), id(F), id(omega), id(Omega)):
+            raise ValueError('DTFT requires var to be f, F, omega, or Omega`, not %s' % var)
 
-        # TODO, handle evaluation keyword
-        return fexpr(summation(self.subs(nsym).expr * exp(-2 * j * pi * fsym * nsym * dt), (nsym, -oo, oo)))
+        dtft = DTFT(self.expr, self.var, fsym, images=images)
 
-    def DTFT(self, **assumptions):
-        """Convert to Fourier domain using discrete time Fourier transform."""
+        result = fexpr(dtft)(var)
+        result = result.expand(diracdelta=True, wrt=var)
+        # There is a bug in SymPy when simplifying Sum('X(n - m)', (m, -oo, oo))
+        # result = result.simplify()
+        result = result.cancel_terms()
+        return result
+
+    def norm_angular_fourier(self, **assumptions):
+
+        from .normomegaexpr import Omega
+        return self.DTFT()(Omega)
     
-        return self.discrete_time_fourier_transform(**assumptions)
-
-    def difference_equation(self, input='x', output='y', form='iir'):
+    def difference_equation(self, inputsym='x', outputsym='y', form='iir'):
         """Create difference equation from impulse response.
 
-        form can be 'fir' or 'iir' ('direct form I').
+        `form` can be 'fir' or 'iir' ('direct form I').
         """
 
         H = self.ZT()
-        return H.difference_equation(input, output, form)
+        return H.difference_equation(inputsym, outputsym, form)
 
     def remove_condition(self):
         """Remove the piecewise condition from the expression."""
@@ -192,10 +216,16 @@ class DiscreteTimeDomainExpression(DiscreteTimeDomain, SequenceExpression):
 def nexpr(arg, **assumptions):
     """Create nExpr object.  If `arg` is nsym return n"""
 
+    from .expr import Expr
+    from .seq import seq
+    
     if arg is nsym:
         return n
 
-    from .seq import seq
+    if isinstance(arg, Expr):
+        if assumptions == {}:
+            return arg
+        return arg.__class__(arg, **assumptions)
     
     if isinstance(arg, str) and arg.startswith('{'):
         return seq(arg)
@@ -212,4 +242,4 @@ from .expressionclasses import expressionclasses
 
 classs = expressionclasses.register('discrete time', DiscreteTimeDomainExpression)
 
-n = DiscreteTimeDomainExpression('n')
+n = DiscreteTimeDomainExpression('n', integer=True)
