@@ -7,7 +7,7 @@ Copyright 2014--2021 Michael Hayes, UCECE
 
 from __future__ import division
 from .domains import AngularFourierDomain
-from .fourier import inverse_fourier_transform
+from .inverse_fourier import inverse_fourier_transform
 from .expr import Expr, expr, expr_make
 from .sym import fsym, ssym, tsym, omegasym, omega0sym, j, pi
 from .units import u as uu
@@ -24,10 +24,10 @@ class AngularFourierDomainExpression(AngularFourierDomain, Expr):
 
         super(AngularFourierDomainExpression, self).__init__(val, **assumptions)
 
-        if self.expr.find(ssym) != set():
+        if self.expr.has(ssym):
             raise ValueError(
                 'omega-domain expression %s cannot depend on s' % self.expr)
-        if self.expr.find(tsym) != set():
+        if self.expr.has(tsym):
             raise ValueError(
                 'omega-domain expression %s cannot depend on t' % self.expr)
 
@@ -60,6 +60,22 @@ class AngularFourierDomainExpression(AngularFourierDomain, Expr):
         result = self.subs(2 * pi * f)
         return result
 
+    def norm_fourier(self, **assumptions):
+        """Convert to normalized Fourier domain."""
+        from .symbols import F
+        from .dsym import dt
+        
+        result = self.subs(2 * pi * F / dt)
+        return result
+
+    def norm_angular_fourier(self, **assumptions):
+        """Convert to normalized angular Fourier domain."""
+        from .symbols import Omega
+        from .dsym import dt
+        
+        result = self.subs(Omega / dt)
+        return result        
+
     def laplace(self, **assumptions):
         """Convert to Laplace domain."""
 
