@@ -6,9 +6,8 @@ Copyright 2016--2020 Michael Hayes, UCECE
 
 from __future__ import division
 import sympy as sym
-from sympy.core.mul import _unevaluated_Mul as uMul
-from sympy.core.add import _unevaluated_Add as uAdd
 from .sym import sympify, AppliedUndef
+from .utils import pair_conjugates
 
 class Pole(object):
 
@@ -168,7 +167,7 @@ def _zp2tf(zeros, poles, K=1, var=None):
     else:
         pp = [1 / (var - p) ** poles[p] for p in poles]
         
-    return uMul(K, *(zz + pp))
+    return sym.Mul(K, *(zz + pp), evaluate=False)
 
 
 def _tc2tf(zeros, poles, K=1, var=None):
@@ -215,7 +214,7 @@ def _tc2tf(zeros, poles, K=1, var=None):
                 K /= p ** o        
 
     K = K.simplify()
-    return uMul(K, *(zz + pp))
+    return sym.Mul(K, *(zz + pp), evaluate=False)
 
 
 def _pr2tf(poles, residues, var=None):
@@ -225,7 +224,7 @@ def _pr2tf(poles, residues, var=None):
     poles = sympify(poles)
     residues = sympify(residues)
 
-    return uAdd(*[r / (var - p) for r, p in zip(residues, poles)])
+    return sym.Add(*[r / (var - p) for r, p in zip(residues, poles)], evaluate=False)
 
 
 def as_ratfun_delay(expr, var):
@@ -423,7 +422,7 @@ class Ratfun(object):
             return n / ddenom.subs(pole)
 
         m2 = method2(numer, denom, var, pole)        
-        return m2
+        return m2.cancel()
 
 
     @property
@@ -549,6 +548,7 @@ class Ratfun(object):
         See also canonical, standard, general, timeconst, and ZPK
 
         """
+        
         try:
             Q, R, D, delay, undef = self.as_QRD(combine_conjugates, damping)
         except ValueError:
@@ -617,25 +617,39 @@ class Ratfun(object):
         N = N / K
         return sym.Mul(N, sym.Pow(D, -1), evaluate=False) * sym.exp(self.var * delay) * undef
 
-    def ZPK(self):
+    def ZPK(self, combine_conjugates=False):
         """Convert to zero-pole-gain (ZPK) form.
 
         See also canonical, general, standard, timeconst, and partfrac"""
 
-        N, D, delay, undef = self.as_ratfun_delay_undef()
+        zeros, poles, K, undef = self.as_ZPK()
 
-        var = self.var        
-        Npoly = sym.Poly(N, var)
-        Dpoly = sym.Poly(D, var)
+        var = self.var
         
-        K = sym.cancel(Npoly.LC() / Dpoly.LC())
-        if delay != 0:
-            K *= sym.exp(self.var * delay)
+        if not combine_conjugates:
+            return _zp2tf(zeros, poles, K, var) * undef
 
-        zeros = sym.roots(Npoly)
-        poles = sym.roots(Dpoly)
+        pole_pairs, pole_singles = pair_conjugates(poles)
+        zero_pairs, zero_singles = pair_conjugates(zeros)
 
-        return _zp2tf(zeros, poles, K, self.var) * undef
+        result1 = 1
+        num = 1
+        for zeros, order in zero_pairs.items():
+            for m in range(order):
+                num *= (var**2 - zeros[0] * var - zeros[1] * var + zeros[0] * zeros[1]).simplify()
+
+        den = 1
+        for poles, order in pole_pairs.items():
+            for m in range(order):
+                den *= (var**2 - poles[0] * var - poles[1] * var + poles[0] * poles[1]).simplify()
+
+        result1 *= (num / den)
+
+        result2 = _zp2tf(zero_singles, pole_singles, 1, var) * undef
+        result = K * result1 * result2
+        
+        return result
+        
 
     def residues(self, combine_conjugates=False, damping=None):
         """Return residues of partial fraction expansion.
@@ -689,6 +703,27 @@ class Ratfun(object):
 
         return self.Ddegree > self.Ndegree
 
+    def as_ZPK(self):
+        """Decompose expression into zeros, poles, gain, undef where
+
+        expression = K * (prod_n (var - z_n) / (prod_n (var - p_n)) * undef
+        """
+                
+        N, D, delay, undef = self.as_ratfun_delay_undef()
+
+        var = self.var        
+        Npoly = sym.Poly(N, var)
+        Dpoly = sym.Poly(D, var)
+        
+        K = sym.cancel(Npoly.LC() / Dpoly.LC())
+        if delay != 0:
+            K *= sym.exp(self.var * delay)
+
+        zeros = sym.roots(Npoly)
+        poles = sym.roots(Dpoly)
+
+        return zeros, poles, K, undef
+    
     def as_QMD(self):
         """Decompose expression into Q, M, D, delay, undef where
 
@@ -760,7 +795,12 @@ class Ratfun(object):
                         R.append(r)
                         D.append(D2 ** n)
             else:
-                D2 = var - p
+                # SymPy reorders the following, for example, s - -1 => 1 + s
+                # D2 = var - p
+                if p == 0:
+                    D2 = var
+                else:
+                    D2 = sym.Add(var, -p, evaluate=False)
 
                 if o == 1:
                     r = sexpr.residue(p, poles)
