@@ -7,7 +7,7 @@ Copyright 2014--2021 Michael Hayes, UCECE
 
 from __future__ import division
 from .domains import LaplaceDomain
-from .laplace import inverse_laplace_transform
+from .inverse_laplace import inverse_laplace_transform
 from .sym import ssym, tsym, j, pi, sympify
 from .ratfun import _zp2tf, _pr2tf, Ratfun
 from .expr import Expr, symbol, expr, ExprDict, exprcontainer, expr_make
@@ -31,12 +31,9 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         super(LaplaceDomainExpression, self).__init__(val, **assumptions)
 
         expr = self.expr        
-        if check and expr.find(tsym) != set() and not expr.has(Integral):
+        if check and expr.has(tsym) and not expr.has(Integral):
             raise ValueError(
                 's-domain expression %s cannot depend on t' % expr)
-        if check and expr.find(tsym) != set() and not expr.has(Integral):
-            raise ValueError(
-                's-domain expression %s cannot depend on t' % self.expr)
 
     def as_expr(self):
         return LaplaceDomainExpression(self)
@@ -109,7 +106,6 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         Otherwise the result is only known for t >= 0.
 
         """
-
         assumptions = self.assumptions.merge(**assumptions)
         result = inverse_laplace_transform(self.expr, self.var, tsym,
                                            **assumptions)
@@ -153,7 +149,7 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         """Convert to Fourier domain."""
         from .symbols import f, jw, pi
 
-        if self.is_causal:
+        if self.is_causal or assumptions.get('causal', False):
             # Note, this does not apply for 1 / s.            
             tmp = self(jw)
             if tmp.real != 0:
@@ -177,6 +173,36 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         result = self.time(**assumptions).angular_fourier(**assumptions)
         return result
 
+    def norm_angular_fourier(self, **assumptions):
+        """Convert to normalized angular Fourier domain."""
+        from .symbols import jw, Omega
+        from .dsym import dt
+        
+        if self.is_causal:
+            # Note, this does not apply for 1 / s.
+            tmp = self(j * Omega / dt)
+            if tmp.real != 0:
+                return self.change(tmp, domain='norm angular fourier',
+                                   **assumptions)                
+        
+        result = self.time(**assumptions).norm_angular_fourier(**assumptions)
+        return result
+
+    def norm_fourier(self, **assumptions):
+        """Convert to normalized Fourier domain."""
+        from .symbols import jw, F
+        from .dsym import dt
+        
+        if self.is_causal:
+            # Note, this does not apply for 1 / s.
+            tmp = self(j * F / dt)
+            if tmp.real != 0:
+                return self.change(tmp, domain='norm fourier',
+                                   **assumptions)                
+        
+        result = self.time(**assumptions).norm_fourier(**assumptions)
+        return result        
+
     def phasor(self, **assumptions):
         """Convert to phasor domain."""
 
@@ -277,7 +303,7 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
 
     def _decompose(self):
 
-        N, D, delay = Ratfun(self, s).as_ratfun_delay()                
+        N, D, delay = self._ratfun.as_ratfun_delay()                
 
         return N, D, delay
 
@@ -313,7 +339,17 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
         return super(LaplaceDomainExpression, self).evaluate(svector)
 
     def plot(self, **kwargs):
-        """Plot pole-zero map."""
+        """Plot pole-zero map.
+
+        kwargs include:
+        axes - the plot axes to use otherwise a new figure is created
+        xlabel - the x-axis label (default Re(s))
+        ylabel - the y-axis label (default Im(s))
+        xscale - the x-axis scaling
+        yscale - the y-axis scaling
+        in addition to those supported by the matplotlib plot command.
+        
+        The plot axes are returned."""
 
         from .plot import plot_pole_zero
         return plot_pole_zero(self, **kwargs)
@@ -326,103 +362,32 @@ class LaplaceDomainExpression(LaplaceDomain, Expr):
     def bode_plot(self, fvector=None, **kwargs):
         """Plot frequency response for a frequency-domain phasor as a Bode
         plot (but without the straight line approximations).  fvector
-        specifies the frequencies.  If it is a tuple (m1, m2), it sets the
-        frequency limits as (10**m1, 10**m2)."""        
+        specifies the frequencies.  If it is a tuple (f1, f2), it sets
+        the frequency limits.   Since a logarithmic frequency scale is used,
+        f1 must be greater than 0.
 
-        return self.phasor().bode_plot(fvector, **kwargs)
-    
-    def parameterize(self, zeta=True):
-        """Parameterize first and second-order expressions.
+        This method makes the assumption that the expression is causal.
 
-        For example, pexpr, defs = expr.parameterize()
+        """        
 
-        If parameterization is successful, defs is a dictionary
-        of the paramters.  The original expression can be obtained
-        with pexpr.subs(defs)
+        return self.fourier(causal=True).bode_plot(fvector, **kwargs)
 
-        For first order systems, parameterize as:
+    def nyquist_plot(self, fvector=None, **kwargs):
+        """Plot frequency response for a frequency-domain phasor as a Nyquist
+        plot.  fvector specifies the frequencies.  If it is a tuple
+        (f1, f2), it sets the frequency limits.
 
-        K * (s + beta) / (s + alpha)
+        The points on the plot are geometrically spaced so f1 must be greater
+        than zero.  By default, the mirrored plot for negative frquencies is 
+        shown.  This can be disabled with `mirror = False`.
 
-        K / (s + alpha)
+        The unit circle is shown by default.  This can be disabled with `unitcircle = False`.
 
-        K (s + beta)
+        This method makes the assumption that the expression is causal.
+        """        
 
-        where appropriate.
-
-        If `zeta` is True, parameterize second-order expression in
-        standard form using damping factor and natural frequency
-        representation, i.e.
-
-        N(s) / (s**2 + 2 * zeta * omega_0 * s + omega_0**2)
-        
-        otherwise parameterize as
-        
-        N(s) / (s**2 + 2 * sigma_1 * s + omega_1**2 + sigma_1**2)
-
-        """
-
-        def def1(defs, symbolname, value):
-            from .cexpr import cexpr
-            
-            sym1 = symbol(symbolname)
-            defs[symbolname] = cexpr(value)
-            return sym1
-
-        factors = self.as_ordered_factors()
-
-        spowers = [s**-4, s**-3, s**-2, s**-1, s, s**2, s**3, s**4]
-        for spower in spowers:
-            if spower in factors:
-                result, defs = (self / spower).parameterize(zeta)
-                return result * spower, defs
-        
-        N = self.N
-        D = self.D
-        
-        ndegree = N.degree        
-        ddegree = D.degree
-        ncoeffs = N.coeffs(norm=True)
-        dcoeffs = D.coeffs(norm=True)
-
-        result = None
-        defs = ExprDict()
-
-        K = self.K
-        if ndegree < 1 and ddegree < 1:
-            result = self
-        elif ndegree == 1 and ddegree == 1:
-            K = def1(defs, 'K', K)
-            alpha = def1(defs, 'alpha', dcoeffs[1])
-            beta = def1(defs, 'beta', ncoeffs[1])
-            result = K * (s + beta) / (s + alpha)
-        elif ndegree == 1 and ddegree == 0:
-            K = def1(defs, 'K', K)
-            beta = def1(defs, 'beta', ncoeffs[1])
-            result = K * (s + beta)
-        elif ndegree == 0 and ddegree == 1:
-            K = def1(defs, 'K', K)
-            alpha = def1(defs, 'alpha', dcoeffs[1])
-            result = K / (s + alpha)
-        elif ddegree == 2:
-            K = def1(defs, 'K', K)
-            coeffs = self.N.coeffs()
-
-            if not zeta:
-                sigma1 = def1(defs, 'sigma_1', dcoeffs[1] / 2)
-                omega1 = def1(defs, 'omega_1',
-                              sqrt(dcoeffs[2] - (dcoeffs[1] / 2)**2).simplify())
-                result = K * (self.N / coeffs[0]) / (s**2 + 2 * sigma1 * s + sigma1**2 + omega1**2)
-            else:
-                omega0 = def1(defs, 'omega_0', sqrt(dcoeffs[2]))
-                zeta = def1(defs, 'zeta', dcoeffs[1] / (2 * sqrt(dcoeffs[2])))
-                result = K * (self.N / coeffs[0]) / (s**2 + 2 * zeta * omega0 * s + omega0**2)
-
-        if result is None:
-            # Copy?
-            result = self
-
-        return self.__class__(result, **self.assumptions), defs
+        # Perhaps should assume that causal
+        return self.fourier(causal=True).nyquist_plot(fvector, **kwargs)    
 
     def bilinear_transform(self):
         """Approximate s = ln(z)
@@ -477,7 +442,7 @@ def zp2tf(zeros, poles, K=1, var=None):
     if var is None:
         var = ssym
     return LaplaceDomainTransferFunction(_zp2tf(sympify(zeros), sympify(poles),
-                     sympify(K), var), causal=True)
+                                                sympify(K), var), causal=True)
 
 
 def pr2tf(poles, residues, var=None):
@@ -485,7 +450,8 @@ def pr2tf(poles, residues, var=None):
 
     if var is None:
         var = ssym
-    return LaplaceDomainTransferFunction(_pr2tf(sympify(poles), sympify(residues), var), causal=True)
+    return LaplaceDomainTransferFunction(_pr2tf(sympify(poles), sympify(residues), var),
+                                         causal=True)
 
 
 def sexpr(arg, **assumptions):
