@@ -382,6 +382,8 @@ omegasym = symsymbol('omega', real=True)
 omega0sym = symsymbol('omega_0', real=True)
 tausym = symsymbol('tau', real=True)
 nusym = symsymbol('nu', real=True)
+Omegasym = symsymbol('Omega', real=True)
+Fsym = symsymbol('F', real=True)
 
 pi = sym.pi
 j = sym.I
