@@ -1,4 +1,5 @@
 from lcapy import *
+from lcapy.functions import Eq
 from lcapy.cexpr import ConstantDomainExpression, ConstantFrequencyDomainExpression, ConstantTimeDomainExpression
 from lcapy.fexpr import FourierDomainExpression
 from lcapy.omegaexpr import AngularFourierDomainExpression
@@ -411,6 +412,8 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(Heaviside(t + 1).is_causal, False, "Heaviside(t + 1).is_causal")
         self.assertEqual(Heaviside(2 * t - 1).is_causal, True, "Heaviside(2 * t - 1).is_causal")
         self.assertEqual(Heaviside(-2 * t - 1).is_causal, False, "Heaviside(-2 * t - 1).is_causal")
+
+        self.assertEqual(((Heaviside(t) - Heaviside(t - 7)) * cos(t)).is_causal, True, "expr.is_causal")
         
     def test_has(self):
 
@@ -639,7 +642,13 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(expr(1).magnitude.is_magnitude, True, "is_magnitude")
         self.assertEqual(expr(1).phase.is_phase, True, "is_phase")
         self.assertEqual(expr(1).phase_degrees.is_phase_degrees, True, "is_phase_degrees")
-        self.assertEqual(expr(1).dB.is_dB, True, "is_dB")                
+        self.assertEqual(expr(1).dB.is_dB, True, "is_dB")
+
+    def test_dB(self):
+
+        v = voltage(10)
+        self.assertEqual(v.dB, 20, "voltage(10).dB")
+        self.assertEqual((v**2).dB, 20, "(voltage(10)**2).dB")
 
     def test_simplify_sin_cos(self):
 
@@ -651,3 +660,35 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a.simplify_sin_cos(as_sin=True).simplify(), b, "sin form")
         self.assertEqual(a.simplify_sin_cos().simplify(), b, "default form")        
 
+    def test_poles(self):
+
+        # TODO, maybe tweak ExprDict to make keys Lcapy expressions?
+
+        def D(X):
+            Y = {}
+            for key, arg in X.items():
+                Y[expr(key)] = arg
+            return expr(Y)
+
+        # TODO, need to handle different orderings of complex conjugate pairs
+        
+        # H = 1 / ((s + 5j)**3 * (s-5j)**2 * (s+2))
+        # pairs, singles = H.poles(pairs=True)
+        # epairs = D({(5 * j, -5 * j): 2})
+        # esingles = D({-2: 1, -5 * j: 1})
+        # self.assertEqual(set(pairs.keys()), set(epairs.keys()), "pole pairs")
+        # self.assertEqual(set(singles.keys()), set(esingles.keys()), "pole singles")        
+
+        # H = 1 / ((s + 5j)**2 * (s-5j)**3 * (s+2))
+        # pairs, singles = H.poles(pairs=True)        
+        # epairs = D({(5 * j, -5 * j): 2})
+        # esingles = D({-2: 1, 5 * j: 1})
+        # self.assertEqual(set(pairs.keys()), set(epairs.keys()), "pole pairs")
+        # self.assertEqual(set(singles.keys()), set(esingles.keys()), "pole singles")        
+
+        # H = 1 / ((s + 5j)**2 * (s-5j)**2 * (s+2))
+        # pairs, singles = H.poles(pairs=True)        
+        # epairs = D({(5 * j, -5 * j): 2})
+        # esingles = D({-2: 1})
+        # self.assertEqual(set(pairs.keys()), set(epairs.keys()), "pole pairs")
+        # self.assertEqual(set(singles.keys()), set(esingles.keys()), "pole singles")        
