@@ -20,10 +20,10 @@ class LcapyTester(unittest.TestCase):
         self.assertEqual(a(z)(n), a, "ui(z)(n)")
         self.assertEqual(a(z)(k), 1, "ui(z)(k)")                        
 
-    def test_decompose_AB(self):
+    def test_as_AB(self):
 
         H = (z -2) / (z - 3)
-        A, B = H.decompose_AB()
+        A, B = H.as_AB()
 
         self.assertEqual(A, 1 - 3 / z, "A")
         self.assertEqual(B, 1 - 2 / z, "A")                
@@ -36,34 +36,55 @@ class LcapyTester(unittest.TestCase):
         y = seq((1, 2, 3, 0, 0))
 
         h = seq((1, 2))                
-        
+
         self.assertEqual(x.as_impulses(), e, "as_impulses")
         self.assertEqual(x.zeropad(2), y, "zeropad")
         self.assertEqual(x.prune(), x, "prune")
-        self.assertEqual(y.extent(), 3, "extent")
+        self.assertEqual(y.extent, 3, "extent")
+        self.assertEqual(y.origin, 0, "origin")        
         self.assertEqual(x.convolve(h), seq((1, 4, 7, 6)), "convolve")
-        self.assertEqual(h.ZT(), (z + 2) / z, "ZT")
-        self.assertEqual(h.latex(), r'\left\{\underline{1}, 2\right\}', "latex")                
+        self.assertEqual(h.expr.ZT(), (z + 2) / z, "ZT")
+        self.assertEqual(h.latex(), r'\left\{\underline{1}, 2\right\}', "latex")
         self.assertEqual(seq('1, 2, 3'), x, "seq")
-        self.assertEqual(seq('{1, _2, 3}').latex(), r'\left\{1, \underline{2}, 3\right\}', "latex")
         self.assertEqual(e.seq(), x, "seq")
 
         self.assertEqual(h.n, [0, 1], "seq.n")
+        self.assertEqual(h.expr(z), (z + 2) / z, "h(z)")
 
-        x = seq('{1, _2, 3, 4}')
-        self.assertEqual(x.n, [-1, 0, 1, 2], "seq.n")
-        self.assertEqual(x[0], 2, "seq[0]")        
+        self.assertEqual(h.delay(1), seq((1, 2), origin=-1), "delay")
+        self.assertEqual(h.delay(1), h >> 1, ">>")
+        self.assertEqual(h.delay(-1), h << 1, "<<")                
+
+        q = seq('{1, _2, 3, 4}')
+        self.assertEqual(q.extent, 4, "extent")
+        self.assertEqual(q.origin, 1, "origin")                
+        self.assertEqual(q.n, [-1, 0, 1, 2], "seq.n")
+        self.assertEqual(q[0], 2, "seq[0]")
+        self.assertEqual(q.latex(), r'\left\{1, \underline{2}, 3, 4\right\}', "latex")
+        q.origin = 2
+        self.assertEqual(q.n, [-2, -1, 0, 1], "seq.n with origin 2")        
+
+        a = seq((1, 2, 3), origin=3)
+        self.assertEqual(a.zeroextend().vals, [1, 2, 3, 0], "zeroextend")
+
+        x = seq((1, 2, 3, 4))
+        X = x.DFT()
+        x2 = X.IDFT()
+        self.assertEqual(x, x2, "DFT/IDFT")
+
+        self.assertEqual(h.ZT(), seq((1, 2 / z)), "ZT")
+        self.assertEqual(h.ZT().IZT(), h, "ZT/IZT")
         
     def test_zexpr(self):
 
          H = z / (z - 1)
 
-         DE = H.difference_equation()
+         de = H.difference_equation().separate()
          rhs = expr('x(n)')
          lhs = expr('y(n) - y(n-1)')
 
-         self.assertEqual(DE.lhs, lhs, "DE lhs")
-         self.assertEqual(DE.rhs, rhs, "DE rhs")                  
+         self.assertEqual(de.lhs, lhs, "DE lhs")
+         self.assertEqual(de.rhs, rhs, "DE rhs")                  
 
     def test_nexpr(self):
 
@@ -92,7 +113,7 @@ class LcapyTester(unittest.TestCase):
     def test_dtfilter(self):
 
         a = symbol('a')
-        lpf = DTFilter((1 - a, ), (1, -a))
+        lpf = DLTIFilter((1 - a, ), (1, -a))
 
         y = lpf.response(1, [0], (0,2))
         
@@ -104,6 +125,10 @@ class LcapyTester(unittest.TestCase):
         
         self.assertEqual(y[0], a, "transient response @0")
         self.assertEqual(y[1], a**2, "transient response @1")
+
+    def test_dt_assumptions(self):
+
+        self.assertEqual((1 + 1 / z).is_dc, False, "is_dc")
         
         
         
