@@ -34,23 +34,18 @@ def term_const(expr, var):
     return const, rest
 
 
-def scale_shift(expr, t):
+def scale_shift(expr, var):
+        
+    if expr == var:
+        return sym.S.One, sym.S.Zero
+    
+    if not expr.as_poly(var).is_linear:
+        raise ValueError('Expression not a linear function of %s: %s' % (var, expr))
 
-    if not expr.has(t):
-        raise ValueError('Expression does not contain %s: %s' % (t, expr))
+    scale = expr.coeff(var, 1)
+    shift = expr.coeff(var, 0)        
 
-    terms = expr.as_ordered_terms()
-    if len(terms) > 2:
-        raise ValueError('Expression has too many terms: %s' % expr)
-
-    if len(terms) == 1:
-        return terms[0] / t, sym.S.Zero
-
-    scale = terms[0] / t
-    if scale.has(t):
-        raise ValueError('Expression not a scale and shift: %s' % expr)
-
-    return scale, terms[1]
+    return scale, shift
 
 
 def as_N_D(expr, var, monic_denominator=False):
@@ -124,3 +119,76 @@ def isiterable(arg):
 
     return hasattr(arg, '__iter__')
 
+
+def separate_dirac_delta(expr):
+
+    terms = expr.as_ordered_terms()
+    deltas = []
+    rest = 0
+
+    for term in terms:
+        if term.has(sym.DiracDelta):
+            deltas.append(term)
+        else:
+            rest += term
+            
+    return rest, deltas
+
+
+def remove_images(expr, var, dt, m1=0, m2=0):
+
+    if m2 == 0 and isinstance(m1, tuple) and len(m1) == 2:
+        # Perhaps should warn that this might be deprecated?
+        m1, m2 = m1
+    
+    const, expr1 = factor_const(expr, var)
+
+    result = sym.S.Zero
+    terms = expr1.as_ordered_terms()
+
+    if len(terms) > 1:
+        for term in expr1.as_ordered_terms():
+            result += remove_images(term, var, dt, m1, m2)
+        return const * result
+        
+    if not isinstance(expr1, sym.Sum):
+        return expr
+    sumsym = expr1.args[1].args[0]
+    foo = var - sumsym / dt
+    if not expr1.args[0].has(foo):
+        return expr    
+
+    if m1 == 0 and m2 == 0:
+        return const * expr1.args[0].replace(foo, var)
+
+    return const * sym.Sum(expr1.args[0], (sumsym, m1, m2))
+
+
+def pair_conjugates(poles_dict):
+    """Return dictionary of conjugate pole pairs and a dictionary of the
+    remaining single poles."""
+
+    pole_single_dict = poles_dict.copy()
+    pole_pair_dict = {}
+
+    pole_list = list(poles_dict)
+
+    for i, pole in enumerate(pole_list):
+        pole_c = sym.conjugate(pole)
+        # Check for conjugate pole
+        if pole_c in pole_list[i + 1:]:
+            pole_single_dict.pop(pole, None)
+            pole_single_dict.pop(pole_c, None)
+
+            o1 = poles_dict[pole]
+            o2 = poles_dict[pole_c]            
+            if o1 == o2:
+                pole_pair_dict[pole, pole_c] = o1
+            elif o1 > o2:
+                pole_pair_dict[pole, pole_c] = o2
+                pole_single_dict[pole] = o1 - o2
+            else:
+                pole_pair_dict[pole, pole_c] = o1
+                pole_single_dict[pole_c] = o2 - o1
+
+    return pole_pair_dict, pole_single_dict
