@@ -6,13 +6,14 @@ Copyright 2020--2021 Michael Hayes, UCECE
 
 from __future__ import division
 from .domains import ZDomain
-from .ztransform import inverse_ztransform
-from .sym import j, pi
+from .inverse_ztransform import inverse_ztransform
+from .sym import j, pi, fsym, omegasym
 from .dsym import nsym, ksym, zsym, dt
 from .vector import Vector
 from .ratfun import _zp2tf, Ratfun
 from .dexpr import DiscreteExpression
 from .expr import symbol, expr, ExprDict
+from .diffeq import DifferenceEquation
 from .functions import sqrt, exp
 import numpy as np
 from sympy import Eq, div, limit, oo, Sum
@@ -33,10 +34,10 @@ class ZDomainExpression(ZDomain, DiscreteExpression):
         super(ZDomainExpression, self).__init__(val, **assumptions)
 
         expr = self.expr
-        if check and expr.find(nsym) != set() and not expr.has(Sum):
+        if check and expr.has(nsym) and not expr.has(Sum):
             raise ValueError(
                 'z-domain expression %s cannot depend on n' % expr)
-        if check and expr.find(ksym) != set() and not expr.has(Sum):
+        if check and expr.has(ksym) and not expr.has(Sum):
             raise ValueError(
                 'z-domain expression %s cannot depend on k' % expr)
 
@@ -172,7 +173,18 @@ class ZDomainExpression(ZDomain, DiscreteExpression):
         return super(ZDomainExpression, self).evaluate(svector)
 
     def plot(self, t=None, **kwargs):
-        """Plot pole-zero map."""
+        """Plot pole-zero map.
+
+        kwargs include:
+        unitcircle - if True, draw unit circle
+        axes - the plot axes to use otherwise a new figure is created
+        xlabel - the x-axis label (default Re(z))
+        ylabel - the y-axis label (default Im(z))
+        xscale - the x-axis scaling
+        yscale - the y-axis scaling
+        in addition to those supported by the matplotlib plot command.
+        
+        The plot axes are returned."""
 
         if 'unitcircle' not in kwargs:
             kwargs['unitcircle'] = True
@@ -189,30 +201,44 @@ class ZDomainExpression(ZDomain, DiscreteExpression):
         
         return self.subs((1 + s * dt / 2) / (1 - s * dt / 2))
 
-    def discrete_time_fourier_transform(self, **assumptions):
+    def discrete_time_fourier_transform(self, var=None, images=oo,
+                                        **assumptions):
         """Convert to Fourier domain using discrete time Fourier transform."""
+        return self.DTFT(var, images, **assumptions)        
+        
 
+    def DTFT(self, var=None, images=oo, **assumptions):
+        """Convert to Fourier domain using discrete time Fourier transform."""
         from .symbols import f
 
         if assumptions.get('causal', self.is_causal):
-            return self.subs(exp(j * 2 * pi * f * dt))
+            result = self.subs(exp(j * 2 * pi * f * dt))
+        else:
+            result = self.IZT(**assumptions).DTFT(images=images)
+        return result(var)
 
-        return self.IZT(**assumptions).DTFT()
-
-    def DTFT(self, **assumptions):
-        """Convert to Fourier domain using discrete time Fourier transform."""
-    
-        return self.discrete_time_fourier_transform(**assumptions) 
-
-    def decompose_AB(self):
+    def as_ab(self):
+        """Return lists of denominator and numerator coefficients
+        when the denominator and numerator are expressed as polynomials
+        in z**-1.  The lowest order coefficients are returned first."""
 
         C, R = self.factor_const()
         
-        invz = expr('invz')
-        H = R.replace(z, 1 / invz).factor()
-        r = Ratfun(H, invz.expr)
-        B = ZDomainExpression(r.N).replace(invz, 1 / z)
-        A = ZDomainExpression(r.D).replace(invz, 1 / z)
+        zi = symbol('zi')
+        H = R.replace(z, 1 / zi).cancel()
+        a = H.D.coeffs(zi)
+        b = H.N.coeffs(zi)
+        return a[::-1], list(np.array(b) * C)[::-1]
+
+    def as_AB(self):
+
+        C, R = self.factor_const()
+        
+        zi = symbol('zi')
+        H = R.replace(z, 1 / zi).factor()
+        r = Ratfun(H, zi.expr)
+        B = ZDomainExpression(r.N).replace(zi, 1 / z)
+        A = ZDomainExpression(r.D).replace(zi, 1 / z)
 
         C1, R1 = A.term_const()
         if C1.is_negative:
@@ -221,25 +247,22 @@ class ZDomainExpression(ZDomain, DiscreteExpression):
         
         return A, B * C
     
-    def difference_equation(self, input='x', output='y', form='iir'):
+    def difference_equation(self, inputsym='x', outputsym='y', form='iir'):
         """Create difference equation from transfer function.
 
-        form can be 'fir' or 'iir' ('direct form I').
+        `form` can be 'fir' or 'iir' ('direct form I').
         """
 
         H = self
-        x = nexpr('%s(n)' % input)
-        y = nexpr('%s(n)' % output)
+        x = nexpr('%s(n)' % inputsym)
+        y = nexpr('%s(n)' % outputsym)
 
         X = x.ZT()
         Y = y.ZT()
 
         if form in ('iir', 'direct form I'):
             # Direct form I
-            A, B = self.decompose_AB()
-            
-            lhs = (A * Y).IZT(causal=True)
-            rhs = (B * X).IZT(causal=True)
+            return self.dlti_filter().difference_equation()
             
         elif form == 'fir':
             H = H.partfrac()
@@ -249,14 +272,45 @@ class ZDomainExpression(ZDomain, DiscreteExpression):
         else:
             raise ValueError('Unhandled form ' + form)    
 
-        return DiscreteTimeDomainExpression(Eq(lhs.expr, rhs.expr))        
+        return DifferenceEquation(lhs, rhs, inputsym, outputsym)
+
+    def dlti_filter(self):
+        """Create discrete-time linear time-invariant filter from discrete-time
+        transfer function."""
+
+        # TODO, perhaps add only to DiscreteTimeDomainTransfer?
         
+        from .dltifilter import DLTIFilter
+        
+        if not self.is_rational_function:
+            raise ValueError("Not a rational function")            
+            
+        N = self.N
+        D = self.D
+        n_n = N.coeffs()
+        d_n = D.coeffs()
     
+        if len(n_n) > len(d_n):
+            raise ValueError("System not causal")
+
+        bn = (len(d_n) - len(n_n)) * [0] + n_n
+        an = d_n
+        lpf = DLTIFilter(bn, an) 
+        return lpf
+        
 def zexpr(arg, **assumptions):
     """Create ZDomainExpression object.  If `arg` is zsym return z"""
 
+    from .expr import Expr
+    
     if arg is zsym:
         return z
+
+    if isinstance(arg, Expr):
+        if assumptions == {}:
+            return arg
+        return arg.__class__(arg, **assumptions)
+    
     return ZDomainExpression(arg, **assumptions)
 
 
